@@ -58,16 +58,17 @@ public:
   template <typename TSwap>
   std::istream &Read(std::istream &is)
     {
-    TagField.Read<TSwap>(is);
+    ReadPreValue<TSwap>(is);
     return ReadValue<TSwap>(is);
     }
 
   template <typename TSwap>
-  std::istream &ReadValue(std::istream &is)
+  std::istream &ReadPreValue(std::istream &is)
     {
-    // Superclass
     const Tag itemStart(0xfffe, 0xe000);
     const Tag seqDelItem(0xfffe,0xe0dd);
+
+    TagField.Read<TSwap>(is);
     if( !is )
       {
       //  BogusItemStartItemEnd.dcm
@@ -88,6 +89,15 @@ public:
       throw Exception( "Problem" );
       }
 #endif
+    return is;
+    }
+
+  template <typename TSwap>
+  std::istream &ReadValue(std::istream &is)
+    {
+    // Superclass
+    const Tag itemStart(0xfffe, 0xe000);
+    const Tag seqDelItem(0xfffe,0xe0dd);
     // Self
     SmartPointer<ByteValue> bv = new ByteValue;
     bv->SetLength(ValueLengthField);
@@ -169,7 +179,6 @@ inline std::ostream &operator<<(std::ostream &os, const Fragment &val)
   return os;
 }
 
-
 } // end namespace gdcm
 
 #endif //GDCMFRAGMENT_H
