@@ -96,6 +96,7 @@ public:
     ComprehensiveSR,
     DetachedStudyManagementSOPClass,
     EncapsulatedPDFStorage,
+    EncapsulatedCDAStorage,
     StudyComponentManagementSOPClass,
     DetachedVisitManagementSOPClass,
     DetachedPatientManagementSOPClass,
@@ -116,6 +117,8 @@ public:
     RTIonBeamsTreatmentRecordStorage, // 1.2.840.10008.5.1.4.1.1.481.9
     SurfaceSegmentationStorage, // "1.2.840.10008.5.1.4.1.1.66.5"
     VLWholeSlideMicroscopyImageStorage, // 1.2.840.10008.5.1.4.1.1.77.1.6
+    RTTreatmentSummaryRecordStorage, // 1.2.840.10008.5.1.4.1.1.481.7
+    EnhancedUSVolumeStorage, // 1.2.840.10008.5.1.4.1.1.6.2
     MS_END
   } MSType; // Media Storage Type
 
