@@ -133,6 +133,13 @@ bool Anonymizer::Replace( Tag const &t, const char *value, VL const & vl )
           {
           if( de.GetVR() == VR::SQ )
             {
+            if( vl == 0 && value && *value == 0 )
+              {
+              DataElement de2( t );
+              de2.SetVR( VR::SQ );
+              ds.Replace( de2 );
+              return true;
+              }
             gdcmDebugMacro( "Cannot replace a VR:SQ" );
             return false;
             }
@@ -483,6 +490,11 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
   static const unsigned int numDeIds = sizeof(BasicApplicationLevelConfidentialityProfileAttributes) / deidSize;
   static const Tag *start = BasicApplicationLevelConfidentialityProfileAttributes;
   static const Tag *end = start + numDeIds;
+  if( !CMS )
+    {
+    gdcmErrorMacro( "Need a certificate" );
+    return false;
+    }
 
   CryptographicMessageSyntax &p7 = *CMS;
   //p7.SetCertificate( this->x509 );
@@ -854,8 +866,8 @@ bool Anonymizer::BALCPProtect(DataSet &ds, Tag const & tag, IOD const & iod)
         anonymizedUID = uid.Generate();
         }
 
-        copy.SetByteValue( anonymizedUID.c_str(), anonymizedUID.size() );
-        ds.Replace( copy );
+      copy.SetByteValue( anonymizedUID.c_str(), (uint32_t)anonymizedUID.size() );
+      ds.Replace( copy );
       }
     else
       {
@@ -875,7 +887,7 @@ bool Anonymizer::BALCPProtect(DataSet &ds, Tag const & tag, IOD const & iod)
         }
 
       std::string &v = dummyMapNonUIDTags[ tvk ];
-      copy.SetByteValue( v.c_str(), v.size() );
+      copy.SetByteValue( v.c_str(), (uint32_t)v.size() );
       }
       ds.Replace( copy );
     }
@@ -956,6 +968,11 @@ void Anonymizer::RecurseDataSet( DataSet & ds )
 
 bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
 {
+  if( !CMS )
+    {
+    gdcmErrorMacro( "Need a certificate" );
+    return false;
+    }
   // 1. The application shall decrypt, using its recipient key, one instance of
   // the Encrypted Content (0400,0520) Attribute within the Encrypted
   // Attributes Sequence (0400,0500) and decode the resulting block of bytes
@@ -1073,8 +1090,13 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile2()
   // of the encrypted one ?
   if( !nds2.FindDataElement( Tag(0x8,0x18) ) )
     {
-    gdcmErrorMacro( "Could not find Instance UID" );
-    return false;
+    gdcm::MediaStorage ms;
+    ms.SetFromFile( *F );
+    if( ms != MediaStorage::MediaStorageDirectoryStorage )
+      {
+      gdcmErrorMacro( "Could not find Instance UID" );
+      return false;
+      }
     }
 }
 
