@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -32,7 +31,7 @@ public:
   JPEG16Codec();
   ~JPEG16Codec();
 
-  bool Decode(std::istream &is, std::ostream &os);
+  bool DecodeByStreams(std::istream &is, std::ostream &os);
   bool InternalCode(const char *input, unsigned long len, std::ostream &os);
 
   bool GetHeaderInfo(std::istream &is, TransferSyntax &ts);
