@@ -1,9 +1,8 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL$
 
-  Copyright (c) 2006-2010 Mathieu Malaterre
+  Copyright (c) 2006-2011 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -92,7 +91,12 @@ public:
     }
   void SetBitsAllocated(unsigned short ba)
     {
-    BitsAllocated = ba;
+    if( ba )
+      {
+      BitsAllocated = ba;
+      BitsStored = ba;
+      HighBit = (unsigned short)(ba - 1);
+      }
     }
 
   /// BitsStored see Tag (0028,0101) US Bits Stored
@@ -103,10 +107,10 @@ public:
     }
   void SetBitsStored(unsigned short bs)
     {
-    if( bs <= BitsAllocated )
+    if( bs <= BitsAllocated && bs )
       {
       BitsStored = bs;
-      SetHighBit( BitsStored - 1 );
+      SetHighBit( (unsigned short) (bs - 1) );
       }
     }
 
@@ -157,7 +161,7 @@ public:
   int64_t GetMax() const;
 
   /// return IsValid
-  bool IsValid();
+  bool IsValid() const;
 
   bool operator==(ScalarType st) const
     {
