@@ -223,6 +223,8 @@ static const char * const gdcmMD5SumFiles[][2] = {
 { "64528209839b0369c2da530249f4ca58"  , "TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
 { "2498ca4aaf62991c8a1f629a804bfa44"  , "TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
 { "e4d559b6db04679b54bea40c763b09e4"  , "TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
+{ "58ab110be40303952e05d50e64823192"  , "NM-PAL-16-PixRep1.dcm" },
+{ "deb7e4ee592efca5d475aaa6fab06459"  , "MEDILABInvalidCP246_EVRLESQasUN.dcm" },
 
 { NULL, NULL}
 };
@@ -281,7 +283,8 @@ int TestMD5(int argc, char *argv[])
   if( argc == 2 )
     {
     const char *filename = argv[1];
-    return TestMD5Func(filename, "", true);
+    const char *md5 = GetMD5Sum( filename );
+    return TestMD5Func(filename, md5, true);
     }
 
   // else
