@@ -140,14 +140,14 @@ static const StreamOffset gdcmSelectedTagsOffsetDataFiles[] = {
 { "MR-SIEMENS-DICOM-WithOverlays-extracted-overlays.dcm",42612 },
 { "MR-SIEMENS-DICOM-WithOverlays.dcm",42416 },
 { "MR16BitsAllocated_8BitsStored.dcm",940 },
-{ "MR_ELSCINT1_00e1_1042_SQ_feff_00e0_Item.dcm",-1},
+{ "MR_ELSCINT1_00e1_1042_SQ_feff_00e0_Item.dcm",7704},
 { "MR_GE_with_Private_Compressed_Icon_0009_1110.dcm",20712 },
 { "MR_Philips-Intera_BreaksNOSHADOW.dcm",7618 },
 { "MR_Philips_Intera_No_PrivateSequenceImplicitVR.dcm",9500 },
 { "MR_Philips_Intera_PrivateSequenceExplicitVR_in_SQ_2001_e05f_item_wrong_lgt_use_NOSHADOWSEQ.dcm",7512 },
 { "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm",7018 },
 { "MR_Philips_Intera_SwitchIndianess_noLgtSQItem_in_trueLgtSeq.dcm",9264 },
-{ "MR_SIEMENS_forceLoad29-1010_29-1020.dcm",-1},
+{ "MR_SIEMENS_forceLoad29-1010_29-1020.dcm",60564},
 { "MR_Spectroscopy_SIEMENS_OF.dcm",-1 },
 { "NM-MONO2-16-13x-heart.dcm",1222 },
 { "OT-MONO2-8-a7.dcm",430 },
@@ -161,7 +161,7 @@ static const StreamOffset gdcmSelectedTagsOffsetDataFiles[] = {
 { "PHILIPS_Intera-16-MONO2-Uncompress.dcm",9264 },
 { "PICKER-16-MONO2-Nested_icon.dcm",18228 },
 { "PICKER-16-MONO2-No_DicomV3_Preamble.dcm",1398 },
-{ "PrivateGEImplicitVRBigEndianTransferSyntax16Bits.dcm",-1},
+{ "PrivateGEImplicitVRBigEndianTransferSyntax16Bits.dcm",14972},
 { "RadBWLossLess.dcm",942 },
 { "SIEMENS-12-Jpeg_Process_2_4-Lossy-a.dcm",3044 },
 { "SIEMENS-MR-RGB-16Bits.dcm",49840 },
@@ -176,17 +176,17 @@ static const StreamOffset gdcmSelectedTagsOffsetDataFiles[] = {
 { "SIEMENS_MAGNETOM-12-MONO2-Uncompressed.dcm",5160 },
 { "SIEMENS_MAGNETOM-12-MONO2-VRUN.dcm",5302 },
 { "SIEMENS_MOSAIC_12BitsStored-16BitsJPEG.dcm",105726 },
-{ "SIEMENS_SOMATOM-12-ACR_NEMA-ZeroLengthUs.acr",-1},
+{ "SIEMENS_SOMATOM-12-ACR_NEMA-ZeroLengthUs.acr",5064},
 { "SIEMENS_Sonata-12-MONO2-SQ.dcm",51804 },
 { "SIEMENS_Sonata-16-MONO2-Value_Multiplicity.dcm",25686 },
 { "SignedShortLosslessBug.dcm",1784 },
 { "TG18-CH-2k-01.dcm",2300 },
 { "THERALYS-12-MONO2-Uncompressed-Even_Length_Tag.dcm",1831 },
-{ "TOSHIBA_MRT150-16-MONO2-ACR_NEMA_2.dcm",-1},
+{ "TOSHIBA_MRT150-16-MONO2-ACR_NEMA_2.dcm",1130},
 { "TheralysGDCM120Bug.dcm",8438 },
 { "US-GE-4AICL142.dcm",14072 },
-{ "US-IRAD-NoPreambleStartWith0003.dcm",-1},
-{ "US-IRAD-NoPreambleStartWith0005.dcm",-1},
+{ "US-IRAD-NoPreambleStartWith0003.dcm",3330},
+{ "US-IRAD-NoPreambleStartWith0005.dcm",2490},
 { "US-MONO2-8-8x-execho.dcm",964 },
 { "US-PAL-8-10x-echo.dcm",2416 },
 { "US-RGB-8-epicard.dcm",1000 },
@@ -222,6 +222,8 @@ static const StreamOffset gdcmSelectedTagsOffsetDataFiles[] = {
 { "TOSHIBA_J2K_SIZ1_PixRep0.dcm",  2362  },
 { "TOSHIBA_J2K_OpenJPEGv2Regression.dcm", 2362  },
 { "TOSHIBA_J2K_SIZ0_PixRep1.dcm", 2346  },
+{ "NM-PAL-16-PixRep1.dcm", 4444 },
+{ "MEDILABInvalidCP246_EVRLESQasUN.dcm", 19162 },
 
 /* Stopping condition */
 { 0 ,0 },
