@@ -24,7 +24,7 @@ int TestReadUpToTag(const char* filename, bool verbose = false)
   if( verbose )
   std::cout << "TestRead: " << filename << std::endl;
 
-  std::ifstream is( filename );
+  std::ifstream is( filename, std::ios::binary );
   gdcm::Reader reader;
   reader.SetStream( is );
   // Let's read up to Pixel Data el...
