@@ -96,7 +96,7 @@ static const char * const printmd5[][2] = {
 { "9afc3c3e9d208292430b45867a9981e1" , "dicomdir_Pms_WithVisit_WithPrivate_WithStudyComponents" } ,
 { "356f30be965bbe4e335a56c6c5fe1928" , "dicomdir_With_embedded_icons" } ,
 { "d174a9f2dea0da9e013eb3180317ebbc" , "DMCPACS_ExplicitImplicit_BogusIOP.dcm" } ,
-{ "b160fb6d5d938301d9aa468570f655e4" , "DX_GE_FALCON_SNOWY-VOI.dcm" } ,
+{ "c4aadaeb6c526040dcc035e40ee739a5" , "DX_GE_FALCON_SNOWY-VOI.dcm" } ,
 { "1cbeb77ea2d6e0171dd38e0d6d5cb0b9" , "DX_J2K_0Padding.dcm" } ,
 { "3493bf0e698798529fde6ef488289879" , "ELSCINT1_JP2vsJ2K.dcm" } ,
 { "8f5581be656bd6f1ab6c9ec94f302284" , "ELSCINT1_LOSSLESS_RICE.dcm" } ,
@@ -119,7 +119,7 @@ static const char * const printmd5[][2] = {
 { "61ca6c5115e6f74565f6f2ca06647444" , "GE_DLX-8-MONO2-PrivateSyntax.dcm" } ,
 { "2ed065d325227d88abfaaa7b6b693b75" , "GE_GENESIS-16-MONO2-Uncompressed-UnusualVR.dcm" } ,
 { "8d398fce426d3a248d8c3f7582e3751d" , "GE_GENESIS-16-MONO2-WrongLengthItem.dcm" } ,
-{ "e854973d5aa7ad3ae6adcaa8cf9ef170" , "GE_LOGIQBook-8-RGB-HugePreview.dcm" } ,
+{ "bb5d500a0391a399b035968496b6fd5d" , "GE_LOGIQBook-8-RGB-HugePreview.dcm" } ,
 { "4baf83d23aa101ba8853193478764bda" , "GE_MR_0025xx1bProtocolDataBlock.dcm" } ,
 { "d5efa34d8091e1ad04683eefb41f33c7" , "GE_RHAPSODE-16-MONO2-JPEG-Fragments.dcm" } ,
 { "d41d8cd98f00b204e9800998ecf8427e" , "IM-0001-0066.dcm" } ,
@@ -165,7 +165,7 @@ static const char * const printmd5[][2] = {
 { "5797c9dfe94e4a4bccfbf81ab0aaa957" , "MR-SIEMENS-DICOM-WithOverlays.dcm" } ,
 { "df28467760104edc923d0625a0e2a778" , "MR-SIEMENS-DICOM-WithOverlays-extracted-overlays.dcm" } ,
 { "bf324a1c91d3a09d9136f54f5910e570" , "MR_SIEMENS_forceLoad29-1010_29-1020.dcm" } ,
-{ "9d8b55ae15d62e35ec861132f80f3f17" , "MR_Spectroscopy_SIEMENS_OF.dcm" } ,
+{ "f4df164cd5dbfd69f48fd3bfd5f85a8c" , "MR_Spectroscopy_SIEMENS_OF.dcm" } ,
 { "1a5646a7b05840813c067d8c8dfa507e" , "NM-MONO2-16-13x-heart.dcm" } ,
 { "8d8c3b8eb830b57b162e7c9f2d64b214" , "OsirixFake16BitsStoredFakeSpacing.dcm" } ,
 { "bf793beb0e96f2399e467409e3cf5311" , "OT-MONO2-8-a7.dcm" } ,
@@ -197,7 +197,7 @@ static const char * const printmd5[][2] = {
 { "417457750452158c40f7257f0523feea" , "SIEMENS_MAGNETOM-12-MONO2-GDCM12-VRUN.dcm" } ,
 { "a15300a90340c4b4c8d15af91a7cb71e" , "SIEMENS_MAGNETOM-12-MONO2-Uncompressed.dcm" } ,
 { "90102b10f80b6490209717435321c542" , "SIEMENS_MAGNETOM-12-MONO2-VRUN.dcm" } ,
-{ "9ca5aebcd31ea271799858c32df18524" , "SIEMENS_MOSAIC_12BitsStored-16BitsJPEG.dcm" } ,
+{ "082dbd9bea567b86cc4415d66ff158e5" , "SIEMENS_MOSAIC_12BitsStored-16BitsJPEG.dcm" } ,
 { "be0b7098b442990aebf3364d747af482" , "SIEMENS-MR-RGB-16Bits.dcm" } ,
 { "47510716d1038c4764f672ece69f2e3c" , "SIEMENS_SOMATOM-12-ACR_NEMA-ZeroLengthUs.acr" } ,
 { "5fc4be2074b6186d3993818cd1baeb89" , "SIEMENS_Sonata-12-MONO2-SQ.dcm" } ,
@@ -210,9 +210,9 @@ static const char * const printmd5[][2] = {
 { "beda2947fcc433aa0c694377a23b553d" , "TheralysGDCM120Bug.dcm" } ,
 { "e8819809884c214fe78ee2b227417e5c" , "TOSHIBA_MRT150-16-MONO2-ACR_NEMA_2.dcm" } ,
 { "e6e83ba0c5435ad355767cd5eb9512b6" , "undefined_length_un_vr.dcm" } ,
-{ "54bcddcbac5e2a875b4c72736f727aa8" , "US-GE-4AICL142.dcm" } ,
-{ "b894d6f1bf24b583fde241ee0b2cf3d5" , "US-IRAD-NoPreambleStartWith0003.dcm" } ,
-{ "d9ede0f035b532025cf47630f350ea22" , "US-IRAD-NoPreambleStartWith0005.dcm" } ,
+{ "787ca80c8dd1aa619d5f85610862380b" , "US-GE-4AICL142.dcm" } ,
+{ "f1e9c893391e1d458cffa2a1e0904160" , "US-IRAD-NoPreambleStartWith0003.dcm" } ,
+{ "d1d9be67c9d066fabc8e1c4ae124f9a0" , "US-IRAD-NoPreambleStartWith0005.dcm" } ,
 { "17222122d388f2c1185884c644c041db" , "US-MONO2-8-8x-execho.dcm" } ,
 { "d58a4930f5b436939d297730b883d5b9" , "US-PAL-8-10x-echo.dcm" } ,
 { "e0552f839d327506c32c4b9ceeb56459" , "US-RGB-8-epicard.dcm" } ,
@@ -223,6 +223,11 @@ static const char * const printmd5[][2] = {
 { "2e039bbc7520f809963e051ff5144ccf" , "UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" },
 { "0a90894370ba84dbe31acd1290ff9999" , "NM_Kakadu44_SOTmarkerincons.dcm" },
 { "504f0fae0f9e6e1ed2a03a5c96c0500f" , "PhilipsInteraSeqTermInvLen.dcm" },
+{ "2940bd46f097f79012d24f47504c3c8c" , "TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
+{ "696917fea41e83b9980bad82b609162c" , "TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
+{ "7ef3da46c43e51cfe2eb82e4d23dd623" , "TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
+{ "7f69568a362343fe7ff0266db7b3614f" , "NM-PAL-16-PixRep1.dcm" },
+{ "8272b02db757629bf21b2cbea24e6e93" , "MEDILABInvalidCP246_EVRLESQasUN.dcm" },
 
 { 0 ,0 }
 };
